/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.spray;

import java.util.Collection;
import nl.cloudfarming.client.field.model.Field;
import nl.cloudfarming.client.field.model.TreatmentZone;
import nl.cloudfarming.client.fleet.model.Implement;
import nl.cloudfarming.client.fleet.model.Vehicle;
import nl.cloudfarming.client.model.Entity;
import nl.cloudfarming.client.model.ItemIdType;
import nl.cloudfarming.client.task.Task;

/**
 *
 * @author Maciek Dulkiewicz <maciek.dulkiewicz@ordina.nl>
 */
public class SprayTask extends Task {

    public static final String EXT = "stk";
    public static final String MIME_TYPE = "application/x-agrosense-spray-task";
    public static final Class[] requires = new Class[]{
        Field.class,
        TreatmentZone.class,
        Vehicle.class,
        Implement.class
    };

    public SprayTask(Collection<? extends Entity> entities) {
        super(entities.iterator().next().getURI(), requires, ItemIdType.STK);
        for (Entity entity : entities) {
            getContext().addItem(entity);
        }
    }

    public SprayTask(Entity entity) {
        super(entity.getURI(), requires, ItemIdType.STK);
        getContext().addItem(entity);
    }

    public boolean hasEntitiesOfClass(Class clazz) {
        Collection foundObjects = getContext().lookupAll(clazz);
        return foundObjects.size() > 0;
    }

    @Override
    public Class[] getRequiredClasses() {
        return requires;
    }
}
