/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.spray;

import java.awt.event.ActionEvent;
import java.util.Arrays;
import java.util.List;
import javax.swing.AbstractAction;
import javax.swing.Action;
import javax.swing.SwingUtilities;
import nl.cloudfarming.client.model.Entity;
import nl.cloudfarming.client.task.TaskService;
import org.openide.awt.ActionID;
import org.openide.awt.ActionReference;
import org.openide.awt.ActionReferences;
import org.openide.awt.ActionRegistration;
import org.openide.util.*;

/**
 *
 * @author Maciek Dulkiewicz <maciek.dulkiewicz@ordina.nl>
 */
@ActionID(category = "Task", id = "nl.cloudfarming.client.task.spray.SprayTaskAction")
@ActionRegistration(iconBase = "nl/cloudfarming/client/task/shape/clipboard_sign.png", displayName = "#createSprayTask")
//@ActionReferences(value = {
//    @ActionReference(path = "Loaders/application/x-agrosense-field/Actions", position = 3000)})
@NbBundle.Messages("createSprayTask=Create spray task")
public class SprayTaskAction extends AbstractAction implements LookupListener, ContextAwareAction {

    private Lookup context;
    private Lookup.Result<Entity> lkpInfo;

    public SprayTaskAction() {
        this(Utilities.actionsGlobalContext());
    }

    public SprayTaskAction(Lookup context) {
        putValue(Action.NAME, Bundle.createSprayTask());
        this.context = context;
    }

    void init() {
        assert SwingUtilities.isEventDispatchThread() : "this shall be called just from AWT thread";

        if (lkpInfo != null) {
            return;
        }

        //The thing we want to listen for the presence or absence of
        //on the global selection
        lkpInfo = context.lookupResult(Entity.class);
        lkpInfo.addLookupListener(this);
        resultChanged(null);
    }

    @Override
    public boolean isEnabled() {
        init();
        return super.isEnabled();
    }

    @Override
    public void actionPerformed(ActionEvent e) {
        init();
        SprayTask task = new SprayTask(lkpInfo.allInstances());
        SprayTaskManager sprayTaskManager = Lookup.getDefault().lookup(SprayTaskManager.class);
        TaskService taskService = Lookup.getDefault().lookup(TaskService.class);
        sprayTaskManager.addSprayTask(task);
        taskService.activateTask(task);
    }

    private boolean selectedEntitiesAreValid() {
        //Get all classes required by the SprayTask
        List<Class> requiredClasses = Arrays.asList(SprayTask.requires);

        //Check that the class of each selected entity is actually required
        for (Class clazz : lkpInfo.allClasses()) {
            //if a selected class is not required, we cant use it and the action is disabled
            if (!requiredClasses.contains(clazz)) {
                return false;
            }
        }

        return true;
    }

    @Override
    public void resultChanged(LookupEvent ev) {
        if (lkpInfo.allInstances().isEmpty()) {
            setEnabled(false);
        } else {
            setEnabled(selectedEntitiesAreValid());
        }
    }

    @Override
    public Action createContextAwareInstance(Lookup context) {
        return new SprayTaskAction(context);
    }
}
