/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.spray;

import java.awt.BorderLayout;
import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;
import javax.swing.JComponent;
import javax.swing.JToolBar;
import nl.cloudfarming.client.model.Entity;
import nl.cloudfarming.client.spray.windows.SprayTaskContextPanel;
import nl.cloudfarming.client.task.Task;
import nl.cloudfarming.client.task.TaskService;
import nl.cloudfarming.client.util.swing.ASBodyPanel;
import org.netbeans.core.spi.multiview.CloseOperationState;
import org.netbeans.core.spi.multiview.MultiViewElement;
import org.netbeans.core.spi.multiview.MultiViewElementCallback;
import org.openide.util.ImageUtilities;
import org.openide.util.Lookup;
import org.openide.util.LookupEvent;
import org.openide.util.LookupListener;
import org.openide.util.NbBundle.Messages;
import org.openide.windows.TopComponent;

@MultiViewElement.Registration(
    displayName = "#LBL_SprayTask_VISUAL",
iconBase = "nl/cloudfarming/client/spray/to_do_list_checked_1.png",
mimeType = SprayTask.MIME_TYPE,
persistenceType = TopComponent.PERSISTENCE_NEVER,
preferredID = "SprayTaskVisual",
position = 2000)
@Messages({
    "LBL_SprayTask_VISUAL=Task context",})
public final class SprayTaskVisualElement extends TopComponent implements MultiViewElement, LookupListener, PropertyChangeListener {

    private SprayTaskDataObject obj;
    private JToolBar toolbar = new JToolBar();
    private transient MultiViewElementCallback callback;
    private SprayTask task;
    private SprayTaskContextPanel panel;
    private ASBodyPanel panelDecorator;
    private Lookup lookup;

    public SprayTaskVisualElement(Lookup lkp) {
        this(lkp.lookup(SprayTask.class));
        lookup = lkp;
        obj = lookup.lookup(SprayTaskDataObject.class);
        assert obj != null;
    }

    public SprayTaskVisualElement(SprayTask task) {
        initComponents();

        setLayout(new BorderLayout());
        panel = new SprayTaskContextPanel(task);
        panelDecorator = new ASBodyPanel(panel);
        add(panelDecorator);
        panelDecorator.setIcon(ImageUtilities.loadImageIcon("nl/cloudfarming/client/spray/windows/task32.png", false));

        this.task = task;
        updateHeader();
        updateContextState();
    }

    private void updateHeader() {
        panelDecorator.setTitle(task.getName());
        setName(task.getName());

        if (callback != null) {
            String name = task.getName();
            TopComponent tc = callback.getTopComponent();
            tc.setHtmlDisplayName(name);
            tc.setDisplayName(name);
            tc.setName(getName());
            tc.setToolTipText(getToolTipText());
        }
    }

    @Override
    public int getPersistenceType() {
        return TopComponent.PERSISTENCE_NEVER;
    }

    @Override
    public void componentOpened() {
        task.getLookup().lookupResult(Entity.class).addLookupListener(this);
        task.addPropertyChangeListener(this);
    }

    @Override
    public void componentActivated() {
        //make sure the task shown in this overview is active
        //so the AddToActiveTask action works on this task
        if (task != null) {
            Lookup.getDefault().lookup(TaskService.class).activateTask(task);
        }
    }

    @Override
    public void componentClosed() {
        task.getLookup().lookupResult(Entity.class).removeLookupListener(this);
        task.removePropertyChangeListener(this);
    }

    void writeProperties(java.util.Properties p) {
        // better to version settings since initial version as advocated at
        // http://wiki.apidesign.org/wiki/PropertyFiles
        p.setProperty("version", "1.0");
        // TODO store your settings
    }

    void readProperties(java.util.Properties p) {
        String version = p.getProperty("version");
        // TODO read your settings according to their version
    }

    private void updateContextState() {
//        panel.updateFieldState(task.hasEntitiesOfClass(Field.class), (List) task.getLookup().lookupAll(Field.class));
//        panel.updateTreatmentZoneState(task.hasEntitiesOfClass(TreatmentZone.class), (List) task.getLookup().lookupAll(TreatmentZone.class));
//        panel.updateVehicleState(task.hasEntitiesOfClass(Vehicle.class), (List) task.getLookup().lookupAll(Vehicle.class));
//        panel.updateImplementState(task.hasEntitiesOfClass(Implement.class), (List) task.getLookup().lookupAll(Implement.class));
    }

    @Override
    public void resultChanged(LookupEvent le) {
        updateContextState();
    }

    @Override
    public Lookup getLookup() {
        return lookup;
    }

    /**
     * This method is called from within the constructor to initialize the form.
     * WARNING: Do NOT modify this code. The content of this method is always
     * regenerated by the Form Editor.
     */
    // <editor-fold defaultstate="collapsed" desc="Generated Code">//GEN-BEGIN:initComponents
    private void initComponents() {

        javax.swing.GroupLayout layout = new javax.swing.GroupLayout(this);
        this.setLayout(layout);
        layout.setHorizontalGroup(
            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGap(0, 400, Short.MAX_VALUE)
        );
        layout.setVerticalGroup(
            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGap(0, 300, Short.MAX_VALUE)
        );
    }// </editor-fold>//GEN-END:initComponents

    // Variables declaration - do not modify//GEN-BEGIN:variables
    // End of variables declaration//GEN-END:variables
    @Override
    public JComponent getVisualRepresentation() {
        return this;
    }

    @Override
    public JComponent getToolbarRepresentation() {
        return toolbar;
    }

    @Override
    public void componentShowing() {
        if (callback != null) {
            updateHeader();
        }
    }

    @Override
    public void componentHidden() {
    }

    @Override
    public void componentDeactivated() {
    }

    @Override
    public void setMultiViewCallback(MultiViewElementCallback callback) {
        this.callback = callback;
    }

    @Override
    public CloseOperationState canCloseElement() {
        return CloseOperationState.STATE_OK;
    }

    @Override
    public void propertyChange(PropertyChangeEvent evt) {
        if (evt.getPropertyName().equalsIgnoreCase(Task.PROP_NAME)) {
            updateHeader();
        }
    }
}
