/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.spray;

import nl.cloudfarming.client.field.model.TreatmentZone;
import nl.cloudfarming.client.task.Task;
import nl.cloudfarming.client.task.button.ItemSelectButton;
import org.openide.util.ImageUtilities;
import org.openide.util.NbBundle.Messages;

/**
 * This button can be used to produce treatmentzones for the active task. 
 * It uses the actionPerformed of the ItemSelectButton superclass to search 
 * for TaskObjectFactories able to produce treatmentzones for the active task in the lookup.
 * - If one is found, that one will be started
 * - If more then one is found the user will be presented a selection windows to select the source of treatmentzones. 
 * The correct wizard is started after the user clicks finish.
 * 
 * Usage: Create an instance of this button and add it to your panel.
 * 
 * Creation of new selectionbutton: Create necessary taskobjectfactory(s), copy this class, adjust static variables to suit your needs.
 * 
 * @author Gerben Feenstra
 */

@Messages({
    "TreatmentZoneSelectButton_toolTipText=Click to add treatment zone",
    "TreatmentZoneSelectButton_text=Treatmentzone",
    "TreatmentZoneSelectButton_wizard_panel_title=Select treatmentzone source",
    "TreatmentZoneSelectButton_wizard_panel_text=Select the source for treatmentzones. The wizard will convert the selected item(s) to treatmentzone(s).",

})
public class TreatmentZoneSelectButton extends ItemSelectButton {
    
    private static final String PANEL_TITLE = Bundle.TreatmentZoneSelectButton_wizard_panel_title();
    private static final String PANEL_TEXT = Bundle.TreatmentZoneSelectButton_wizard_panel_text();
    private static final String BUTTON_ICON = "nl/cloudfarming/client/field/type/buttons/treatmentzone32.png";
    private static final String BUTTON_TITLE = Bundle.TreatmentZoneSelectButton_text();
    private static final String BUTTON_TOOLTIP = Bundle.TreatmentZoneSelectButton_toolTipText();
    private static final Class TO_SELECT = TreatmentZone.class;
    
    private int selectionMode;      
    
    /**
     * Register this button as listeners of itself so that actionPerformed is called when the button is clicked.
     */
    public TreatmentZoneSelectButton(Task task, int selectionMode){
        super(task, TO_SELECT);
        this.selectionMode = selectionMode;
        // Treatmentzone specific settings select button
        setIcon(ImageUtilities.loadImageIcon(BUTTON_ICON, false));
        setText(BUTTON_TITLE); // Standard = showButtonText, disable by calling showButtonText(false);
        setToolTipText(BUTTON_TOOLTIP);
    }

    @Override
    public String getPanelTitle() {
        return PANEL_TITLE;
    }

    @Override
    public String getPanelText() {
        return PANEL_TEXT;
    }

    @Override
    public String getButtonText() {
        return BUTTON_TITLE;
    }

    @Override
    public int getSelectionMode() {
        return selectionMode;
    }
}
