/*
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 * 
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *          http://www.eclipse.org/legal/epl-v10.html
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.spray;

import nl.cloudfarming.client.fleet.model.Vehicle;
import nl.cloudfarming.client.task.Task;
import nl.cloudfarming.client.task.button.ItemSelectButton;
import org.openide.util.ImageUtilities;
import org.openide.util.NbBundle;

/**
 *
 * @author Maciek Dulkiewicz
 */
@NbBundle.Messages({
    "VehicleSelectButton_text=Vehicle",
    "VehicleSelectButton_toolTipText=Click to add a vehicle",
    "VehicleSelectButton_wizard_panel_title=Select vehicle source",
    "VehicleSelectButton_wizard_panel_text=Select the source for a vehicle.",})
public class VehicleSelectButton extends ItemSelectButton {

    private static final String PANEL_TITLE = Bundle.VehicleSelectButton_wizard_panel_title();
    private static final String PANEL_TEXT = Bundle.VehicleSelectButton_wizard_panel_text();
    private static final String BUTTON_ICON = "nl/cloudfarming/client/fleet/vehicle/steering_wheel_332.png";
    private static final String BUTTON_TEXT = Bundle.VehicleSelectButton_text();
    private static final String BUTTON_TOOLTIP = Bundle.VehicleSelectButton_toolTipText();
    private static final Class TO_SELECT = Vehicle.class;
    //this is a vallue corresponding to a field in ListSelectionModel
    private int selectionMode;

    public VehicleSelectButton(Task task, int selectionMode) {
        super(task, TO_SELECT);
        this.selectionMode = selectionMode;

        setIcon(ImageUtilities.loadImageIcon(BUTTON_ICON, false));
        setText(BUTTON_TEXT); // Standard = showButtonText, disable by calling showButtonText(false);
        setToolTipText(BUTTON_TOOLTIP);
    }

    @Override
    public String getPanelTitle() {
        return PANEL_TITLE;
    }

    @Override
    public String getPanelText() {
        return PANEL_TEXT;
    }

    @Override
    public String getButtonText() {
        return BUTTON_TEXT;
    }

    @Override
    public int getSelectionMode() {
        return selectionMode;
    }
}
